.. _keystone_configuration_options:

==============================
Keystone Configuration Options
==============================

This section provides a list of all possible options and
sample files for keystone configuration.

.. toctree::
   :maxdepth: 2

   config-options.rst
   policy.rst

.. # NOTE(gyee): Sample files are only available in HTML document.
   # Inline sample files with literalinclude hit LaTeX processing error
   # like TeX capacity exceeded and direct links are discouraged in PDF doc.

.. only:: html

   .. toctree::
      :maxdepth: 2

      samples/index.rst
